==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/cs.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedávné stavy",
    "In a meeting" : "Na poradě",
    "Commuting" : "Dojíždění",
    "Out sick" : "Nemocný",
    "Vacationing" : "Dovolená",
    "Working remotely" : "Pracuje na dálku",
    "User status" : "Stav uživatele",
    "Clear status message after" : "Vyčistit stavovou zprávu po uplynutí",
    "What's your status?" : "Jaký je váš stav?",
    "Set status" : "Natavit stav",
    "Online status" : "Stav online",
    "Status message" : "Stavová zpráva",
    "Clear status message" : "Vyčistit stavovou zprávu",
    "Set status message" : "Nastavit stavovou zprávu",
    "There was an error saving the status" : "Došlo k chybě při ukládání stavu",
    "There was an error clearing the status" : "Při čištění stavu došlo k chybě",
    "No recent status changes" : "Žádné nedávné změny stavu",
    "Away" : "Pryč",
    "Do not disturb" : "Nerušit",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Nečistit",
    "Today" : "Dnes",
    "This week" : "Tento týden",
    "Online" : "Online",
    "Invisible" : "Neviditelné",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Při ukládání nového stavu došlo k chybě",
    "30 minutes" : "30 minut",
    "1 hour" : "1 hodina",
    "4 hours" : "4 hodiny",
    "Mute all notifications" : "Ztlumit veškerá upozornění",
    "Appear offline" : "Jevit se offline",
    "Clear status after" : "Vyčistit stav po uplynutí"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/cs.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedávné stavy",
    "In a meeting" : "Na poradě",
    "Commuting" : "Dojíždění",
    "Out sick" : "Nemocný",
    "Vacationing" : "Dovolená",
    "Working remotely" : "Pracuje na dálku",
    "User status" : "Stav uživatele",
    "Clear status message after" : "Vyčistit stavovou zprávu po uplynutí",
    "What's your status?" : "Jaký je váš stav?",
    "Set status" : "Nastavit stav",
    "Online status" : "Stav online",
    "Status message" : "Stavová zpráva",
    "Clear status message" : "Vyčistit stavovou zprávu",
    "Set status message" : "Nastavit stavovou zprávu",
    "There was an error saving the status" : "Došlo k chybě při ukládání stavu",
    "There was an error clearing the status" : "Při čištění stavu došlo k chybě",
    "No recent status changes" : "Žádné nedávné změny stavu",
    "Away" : "Pryč",
    "Do not disturb" : "Nerušit",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Nečistit",
    "Today" : "Dnes",
    "This week" : "Tento týden",
    "Online" : "Online",
    "Invisible" : "Neviditelné",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Při ukládání nového stavu došlo k chybě",
    "30 minutes" : "30 minut",
    "1 hour" : "1 hodina",
    "4 hours" : "4 hodiny",
    "Mute all notifications" : "Ztlumit veškerá upozornění",
    "Appear offline" : "Jevit se offline",
    "Clear status after" : "Vyčistit stav po uplynutí"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
